import React, {useState, useCallback, useEffect} from 'react';
import ReactDOM from 'react-dom';
import { schemeYlOrRd, scaleSequential, max } from 'd3';
import { getMexico } from './getMexico';
import { Marks } from './Marks';
import { tooltipContext } from "./Tooltip";
import { useData } from './useData';
import { Dropdown } from './Dropdown';

const width = 960;
const height = 500;

const states = [
  {value: "MX06", label: "Chihuahua"},
  {value: "MX07", label: "Coahila"},
  {value: "MX19", label: "Nuevo Leon"},
  {value: "MX28", label: "Tamaulipas"},
  {value: "MX25", label: "Sinaloa"},
  {value: "MX10", label: "Durango"},
  {value: "MX32", label: "Zacatecas"},
  {value: "MX24", label: "San Luis Potosi"},
  {value: "MX01", label: "Aguascalientes"},
  {value: "MX14", label: "Jalisco"},
  {value: "MX30", label: "Veracruz"},
  {value: "MX11", label: "Guanajuato"},
  {value: "MX22", label: "Queretaro"},
  {value: "MX31", label: "Yucatan"},
  {value: "MX23", label: "Quintana Roo"},
  {value: "MX13", label: "Hidalgo"},
  {value: "MX04", label: "Campeche"},
  {value: "MX21", label: "Puebla"},
  {value: "MX16", label: "Michoacan"},
  {value: "MX15", label: "Mexico"},
  {value: "MX29", label: "Tlaxcala"},
  {value: "MX08", label: "Colima"},
  {value: "MX09", label: "Distrito Federal"},
  {value: "MX17", label: "Morelos"},
  {value: "MX12", label: "Guerrero"},
  {value: "MX20", label: "Oaxaca"},
  {value: "MX27", label: "Tabasco"},
  {value: "MX05", label: "Chiapas"},
  {value: "MX26", label: "Sonora"},
  {value: "MX02", label: "Baja California"},
  {value: "MX03", label: "Baja California Sur"},
  {value: "MX18", label: "Nayarit"}
  ];

const App = () => {
  const [selectedState, setSelectedState] = useState();
  console.log("selectedState", selectedState)
  const atlasMex = getMexico();
  const wasteData = useData();

  if (!atlasMex || !wasteData) {
    return <pre>Loading...</pre>;
  }
  
  const colorValue = d => d.WasteKgs;
  const colorScale = scaleSequential(scaleSequential)
  	.domain([0, max(wasteData, colorValue)]);

  return (
    <>
      <label for="state-select"> State Select: </label>
      <Dropdown states={states} onSelectedStateChange={setSelectedState} id="state-select"/>
      <svg width={width} height={height}>
        <Marks 
          atlasMex={atlasMex}
          />
    </svg>
      </>
  );
};


const rootElement = document.getElementById('root');
  
ReactDOM.render(<App />, rootElement);